@@ -3,7 +3,10 @@ use warnings;
 
 package Test::File::ShareDir::TempDirObject;
 BEGIN {
-  $Test::File::ShareDir::TempDirObject::VERSION = '0.3.0';
+  $Test::File::ShareDir::TempDirObject::AUTHORITY = 'cpan:KENTNL';
+}
+{
+  $Test::File::ShareDir::TempDirObject::VERSION = '0.3.1';
 }
 
 # ABSTRACT: Internal Object to make code simpler.
@@ -44,7 +47,7 @@ sub _tempdir {
   my ($self) = shift;
   return $self->{tempdir} if exists $self->{tempdir};
   $self->{tempdir} = __dir( __tempdir( CLEANUP => 1 ) );
-  return $self->{tempdir};
+  return $self->{tempdir}->absolute;
 }
 
 sub _module_tempdir {
@@ -52,7 +55,7 @@ sub _module_tempdir {
   return $self->{module_tempdir} if exists $self->{module_tempdir};
   $self->{module_tempdir} = $self->_tempdir->subdir('auto/share/module');
   $self->{module_tempdir}->mkpath();
-  return $self->{module_tempdir};
+  return $self->{module_tempdir}->absolute;
 }
 
 sub _dist_tempdir {
@@ -60,7 +63,7 @@ sub _dist_tempdir {
   return $self->{dist_tempdir} if exists $self->{dist_tempdir};
   $self->{dist_tempdir} = $self->_tempdir->subdir('auto/share/dist');
   $self->{dist_tempdir}->mkpath();
-  return $self->{dist_tempdir};
+  return $self->{dist_tempdir}->absolute;
 }
 
 sub _root {
@@ -98,12 +101,12 @@ sub _dist_share_target_dir {
 
 sub _module_share_source_dir {
   my ( $self, $module ) = @_;
-  return $self->_root->subdir( $self->_modules->{$module} );
+  return __dir( $self->_modules->{$module} )->absolute( $self->_root );
 }
 
 sub _dist_share_source_dir {
   my ( $self, $dist ) = @_;
-  return $self->_root->subdir( $self->_dists->{$dist} );
+  return __dir( $self->_dists->{$dist} )->absolute( $self->_root );
 }
 
 sub _install_module {
@@ -127,7 +130,7 @@ Test::File::ShareDir::TempDirObject - Internal Object to make code simpler.
 
 =head1 VERSION
 
-version 0.3.0
+version 0.3.1
 
 =head1 SYNOPSIS
 
